Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1255)

Unified Diff: chrome/browser/dom_ui/app_launcher_handler.h

Issue 2832014: NTP: Add ability to uninstall apps from the ntp.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/generated_resources.grd ('k') | chrome/browser/dom_ui/app_launcher_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/dom_ui/app_launcher_handler.h
===================================================================
--- chrome/browser/dom_ui/app_launcher_handler.h (revision 50261)
+++ chrome/browser/dom_ui/app_launcher_handler.h (working copy)
@@ -35,12 +35,15 @@
// Populate a dictionary with the information from an extension.
static void CreateAppInfo(Extension* extension, DictionaryValue* value);
- // Callback for the "getAll" message.
+ // Callback for the "getApps" message.
void HandleGetApps(const Value* value);
// Callback for the "launch" message.
void HandleLaunchApp(const Value* value);
+ // Callback for the "uninstallApp" message.
+ void HandleUninstallApp(const Value* value);
+
private:
// Starts the animation of the app icon.
void AnimateAppIcon(Extension* extension, const gfx::Rect& rect);
@@ -35,12 +35,15 @@
void HandleGetApps(const Value* value);
- // Callback for the "launch" message.
+ // Callback for the "launchApp" message.
void HandleLaunchApp(const Value* value);
« no previous file with comments | « chrome/app/generated_resources.grd ('k') | chrome/browser/dom_ui/app_launcher_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698